@@ -240,12 +240,8 @@ fn values_to_vec(values: Option<clap::parser::ValuesRef<String>>) -> Vec<String>
 fn validate_plugin_args_when_no_files(plugins: &[String]) -> Result<()> {
   for (i, plugin) in plugins.iter().enumerate() {
     let lower_plugin = plugin.to_lowercase();
-    let is_valid_plugin = lower_plugin.ends_with(".wasm")
-      || lower_plugin.ends_with(".exe-plugin")
-      || lower_plugin.ends_with(".json")
-      || lower_plugin.contains(".wasm@")
-      || lower_plugin.contains(".exe-plugin@")
-      || lower_plugin.contains(".json@");
+    let is_valid_plugin =
+      lower_plugin.ends_with(".wasm") || lower_plugin.ends_with(".json") || lower_plugin.contains(".wasm@") || lower_plugin.contains(".json@");
     if !is_valid_plugin {
       let start_message = format!(
         "{} was specified as a plugin, but it doesn't look like one. Plugins must have a .wasm or .json extension.",
@@ -280,7 +276,7 @@ fn create_cli_parser(is_outputting_main_help: bool) -> clap::Command {
   app
     .bin_name("dprint")
     .version(env!("CARGO_PKG_VERSION"))
-    .author("Copyright 2020-2022 by David Sherret")
+    .author("Copyright 2020-2023 by David Sherret")
     .about("Auto-formats source code based on the specified plugins.")
     .override_usage("dprint <SUBCOMMAND> [OPTIONS] [--] [file patterns]...")
     .help_template(r#"{bin} {version}
@@ -437,7 +433,7 @@ EXAMPLES:
       Arg::new("config")
         .long("config")
         .short('c')
-        .help("Path or url to JSON configuration file. Defaults to dprint.json or .dprint.json in current or ancestor directory when not provided.")
+        .help("Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.")
         .global(true)
         .num_args(1)
     )
