@@ -16,7 +16,6 @@ use crate::arg_parser::CliArgs;
 use crate::arg_parser::FmtSubCommand;
 use crate::arg_parser::OutputFormatTimesSubCommand;
 use crate::arg_parser::StdInFmtSubCommand;
-use crate::cache::Cache;
 use crate::configuration::resolve_config_from_args;
 use crate::environment::Environment;
 use crate::format::run_parallelized;
@@ -35,11 +34,10 @@ pub async fn stdin_fmt<TEnvironment: Environment>(
   cmd: &StdInFmtSubCommand,
   args: &CliArgs,
   environment: &TEnvironment,
-  cache: &Cache<TEnvironment>,
   plugin_resolver: &PluginResolver<TEnvironment>,
   plugin_pools: Arc<PluginsCollection<TEnvironment>>,
 ) -> Result<()> {
-  let config = resolve_config_from_args(args, cache, environment)?;
+  let config = resolve_config_from_args(args, environment)?;
   let plugins = resolve_plugins_and_err_if_empty(args, &config, environment, plugin_resolver).await?;
   plugin_pools.set_plugins(plugins, &config.base_path)?;
   // if the path is absolute, then apply exclusion rules
@@ -48,7 +46,7 @@ pub async fn stdin_fmt<TEnvironment: Environment>(
     // canonicalize the file path, then check if it's in the list of file paths.
     let resolved_file_path = environment.canonicalize(&cmd.file_name_or_path)?;
     // log the file text as-is since it's not in the list of files to format
-    if !file_matcher.matches(&resolved_file_path) {
+    if !file_matcher.matches(resolved_file_path) {
       environment.log_machine_readable(&cmd.file_text);
       return Ok(());
     }
@@ -82,11 +80,10 @@ pub async fn output_format_times<TEnvironment: Environment>(
   cmd: &OutputFormatTimesSubCommand,
   args: &CliArgs,
   environment: &TEnvironment,
-  cache: &Cache<TEnvironment>,
   plugin_resolver: &PluginResolver<TEnvironment>,
   plugin_pools: Arc<PluginsCollection<TEnvironment>>,
 ) -> Result<()> {
-  let config = resolve_config_from_args(args, cache, environment)?;
+  let config = resolve_config_from_args(args, environment)?;
   let plugins = resolve_plugins_and_err_if_empty(args, &config, environment, plugin_resolver).await?;
   let file_paths = get_and_resolve_file_paths(&config, &cmd.patterns, environment).await?;
   let file_paths_by_plugin = get_file_paths_by_plugins_and_err_if_empty(&plugins, file_paths, &config.base_path)?;
@@ -117,17 +114,16 @@ pub async fn check<TEnvironment: Environment>(
   cmd: &CheckSubCommand,
   args: &CliArgs,
   environment: &TEnvironment,
-  cache: &Cache<TEnvironment>,
   plugin_resolver: &PluginResolver<TEnvironment>,
   plugin_pools: Arc<PluginsCollection<TEnvironment>>,
 ) -> Result<()> {
-  let config = resolve_config_from_args(args, cache, environment)?;
+  let config = resolve_config_from_args(args, environment)?;
   let plugins = resolve_plugins_and_err_if_empty(args, &config, environment, plugin_resolver).await?;
   let file_paths = get_and_resolve_file_paths(&config, &cmd.patterns, environment).await?;
   let file_paths_by_plugin = get_file_paths_by_plugins_and_err_if_empty(&plugins, file_paths, &config.base_path)?;
   plugin_pools.set_plugins(plugins, &config.base_path)?;
 
-  let incremental_file = get_incremental_file(cmd.incremental, &config, cache, &plugin_pools, environment);
+  let incremental_file = get_incremental_file(cmd.incremental, &config, &plugin_pools, environment);
   let not_formatted_files_count = Arc::new(AtomicUsize::new(0));
 
   run_parallelized(
@@ -149,7 +145,7 @@ pub async fn check<TEnvironment: Environment>(
           // correctly formatted file because it hasn't undergone a stable
           // formatting check
           if let Some(incremental_file) = &incremental_file {
-            incremental_file.update_file(file_path, &formatted_text);
+            incremental_file.update_file(&formatted_text);
           }
         }
         Ok(())
@@ -180,17 +176,16 @@ pub async fn format<TEnvironment: Environment>(
   cmd: &FmtSubCommand,
   args: &CliArgs,
   environment: &TEnvironment,
-  cache: &Cache<TEnvironment>,
   plugin_resolver: &PluginResolver<TEnvironment>,
   plugin_pools: Arc<PluginsCollection<TEnvironment>>,
 ) -> Result<()> {
-  let config = resolve_config_from_args(args, cache, environment)?;
+  let config = resolve_config_from_args(args, environment)?;
   let plugins = resolve_plugins_and_err_if_empty(args, &config, environment, plugin_resolver).await?;
   let file_paths = get_and_resolve_file_paths(&config, &cmd.patterns, environment).await?;
   let file_paths_by_plugins = get_file_paths_by_plugins_and_err_if_empty(&plugins, file_paths, &config.base_path)?;
   plugin_pools.set_plugins(plugins, &config.base_path)?;
 
-  let incremental_file = get_incremental_file(cmd.incremental, &config, cache, &plugin_pools, environment);
+  let incremental_file = get_incremental_file(cmd.incremental, &config, &plugin_pools, environment);
   let formatted_files_count = Arc::new(AtomicUsize::new(0));
   let output_diff = cmd.diff;
 
@@ -205,7 +200,7 @@ pub async fn format<TEnvironment: Environment>(
       let incremental_file = incremental_file.clone();
       move |file_path, file_text, formatted_text, had_bom, _, environment| {
         if let Some(incremental_file) = &incremental_file {
-          incremental_file.update_file(file_path, &formatted_text);
+          incremental_file.update_file(&formatted_text);
         }
 
         if formatted_text != file_text {
@@ -1259,84 +1254,26 @@ mod test {
     assert_eq!(environment.read_file(&file_path).unwrap(), "text_formatted");
   }
 
-  #[test]
-  fn should_format_files_with_config_in_config_sub_dir_and_warn() {
-    let file_path1 = "/file1.txt";
-    let file_path2 = "/file2.txt";
-    let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
-      .write_file(file_path1, "text1")
-      .write_file(file_path2, "text2")
-      .with_local_config("./config/.dprintrc.json", |c| {
-        c.add_includes("**/*.txt").add_remote_wasm_plugin();
-      })
-      .initialize()
-      .build();
-
-    run_test_cli(vec!["fmt"], &environment).unwrap();
-
-    assert_eq!(environment.take_stdout_messages(), vec![get_plural_formatted_text(2)]);
-    assert_eq!(environment.take_stderr_messages(), vec![
-            "WARNING: Automatic resolution of the configuration file in the config sub directory will be deprecated soon. Please move the configuration file to the parent directory.",
-            "WARNING: .dprintrc.json will be deprecated soon. Please rename it to dprint.json"
-        ]);
-    assert_eq!(environment.read_file(&file_path1).unwrap(), "text1_formatted");
-    assert_eq!(environment.read_file(&file_path2).unwrap(), "text2_formatted");
-  }
-
   #[test]
   fn should_format_using_config_in_ancestor_directory() {
-    let file_path = "/test/other/file.txt";
-    let environment = TestEnvironmentBuilder::with_initialized_remote_wasm_plugin()
-      .with_default_config(|c| {
-        c.add_includes("**/*.txt");
-      })
-      .write_file(&file_path, "text")
-      .build();
-    environment.set_cwd("/test/other/");
-    run_test_cli(vec!["fmt"], &environment).unwrap();
-    assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
-    assert_eq!(environment.take_stderr_messages().len(), 0);
-    assert_eq!(environment.read_file(&file_path).unwrap(), "text_formatted");
-  }
-
-  #[test]
-  fn should_format_using_old_config_file_name_and_warn() {
-    let file_path = "/test/other/file.txt";
-    let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
-      .with_local_config("/.dprintrc.json", |c| {
-        c.add_remote_wasm_plugin().add_includes("**/*.txt");
-      })
-      .initialize()
-      .set_cwd("/test/other/")
-      .write_file(&file_path, "text")
-      .build();
-    run_test_cli(vec!["fmt"], &environment).unwrap();
-    assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
-    assert_eq!(
-      environment.take_stderr_messages(),
-      vec!["WARNING: .dprintrc.json will be deprecated soon. Please rename it to dprint.json"]
-    );
-    assert_eq!(environment.read_file(&file_path).unwrap(), "text_formatted");
-  }
-
-  #[test]
-  fn should_format_using_config_in_ancestor_directory_config_folder_and_warn() {
-    let file_path = "/test/other/file.txt";
-    let environment = TestEnvironmentBuilder::with_remote_wasm_plugin()
-      .with_local_config("./config/.dprintrc.json", |c| {
-        c.add_includes("**/*.txt").add_remote_wasm_plugin();
-      })
-      .initialize()
-      .set_cwd("/test/other/")
-      .write_file(&file_path, "text")
-      .build();
-    run_test_cli(vec!["fmt"], &environment).unwrap();
-    assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
-    assert_eq!(environment.take_stderr_messages(), vec![
-            "WARNING: Automatic resolution of the configuration file in the config sub directory will be deprecated soon. Please move the configuration file to the parent directory.",
-            "WARNING: .dprintrc.json will be deprecated soon. Please rename it to dprint.json"
-        ]);
-    assert_eq!(environment.read_file(&file_path).unwrap(), "text_formatted");
+    let config_file_names = vec!["dprint.json", "dprint.jsonc", ".dprint.json", ".dprint.jsonc"];
+    for config_file_name in config_file_names {
+      eprintln!("CONFIG FILE: {}", config_file_name);
+      let file_path = "/test/other/file.txt";
+      let environment = TestEnvironmentBuilder::new()
+        .add_remote_wasm_plugin()
+        .with_local_config(format!("/{}", config_file_name), |config_file| {
+          config_file.add_remote_wasm_plugin().add_includes("**/*.txt");
+        })
+        .initialize()
+        .write_file(&file_path, "text")
+        .build();
+      environment.set_cwd("/test/other/");
+      run_test_cli(vec!["fmt"], &environment).unwrap();
+      assert_eq!(environment.take_stdout_messages(), vec![get_singular_formatted_text()]);
+      assert_eq!(environment.take_stderr_messages(), Vec::<String>::new());
+      assert_eq!(environment.read_file(&file_path).unwrap(), "text_formatted");
+    }
   }
 
   #[test]
