@@ -1,7 +1,3 @@
-#![allow(clippy::bool_to_int_with_if)]
-#[cfg(test)]
-#[macro_use]
-extern crate lazy_static;
 #[macro_use]
 mod environment;
 
@@ -13,7 +9,6 @@ use std::sync::Arc;
 use utils::RealStdInReader;
 
 mod arg_parser;
-mod cache;
 mod commands;
 mod configuration;
 mod format;
@@ -49,12 +44,11 @@ async fn run(runtime_handle: tokio::runtime::Handle) -> Result<()> {
     is_stdout_machine_readable: args.is_stdout_machine_readable(),
     runtime_handle: Arc::new(runtime_handle),
   })?;
-  let cache = Arc::new(cache::Cache::new(environment.clone()));
   let plugin_cache = Arc::new(plugins::PluginCache::new(environment.clone()));
   let plugin_pools = Arc::new(plugins::PluginsCollection::new(environment.clone()));
   let plugin_resolver = plugins::PluginResolver::new(environment.clone(), plugin_cache, plugin_pools.clone());
 
-  let result = run_cli::run_cli(&args, &environment, &cache, &plugin_resolver, plugin_pools.clone()).await;
+  let result = run_cli::run_cli(&args, &environment, &plugin_resolver, plugin_pools.clone()).await;
   plugin_pools.drop_and_shutdown_initialized().await;
   result
 }
