@@ -6,14 +6,16 @@ use std::path::PathBuf;
 use anyhow::Result;
 use dprint_core::plugins::PluginInfo;
 
+use super::implementations::WASMER_COMPILER_VERSION;
 use crate::environment::Environment;
 
-const PLUGIN_CACHE_SCHEMA_VERSION: usize = 6;
+const PLUGIN_CACHE_SCHEMA_VERSION: usize = 7;
 
 #[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq)]
 #[serde(rename_all = "camelCase")]
 pub struct PluginCacheManifest {
   schema_version: usize,
+  wasm_cache_version: String,
   plugins: HashMap<String, PluginCacheManifestItem>,
 }
 
@@ -21,6 +23,7 @@ impl PluginCacheManifest {
   pub(super) fn new() -> PluginCacheManifest {
     PluginCacheManifest {
       schema_version: PLUGIN_CACHE_SCHEMA_VERSION,
+      wasm_cache_version: WASMER_COMPILER_VERSION.to_string(),
       plugins: HashMap::new(),
     }
   }
@@ -36,6 +39,34 @@ impl PluginCacheManifest {
   pub fn remove_item(&mut self, key: &str) -> Option<PluginCacheManifestItem> {
     self.plugins.remove(key)
   }
+
+  fn is_different_schema(&self) -> bool {
+    self.schema_version != PLUGIN_CACHE_SCHEMA_VERSION
+  }
+
+  fn is_new_wasm_cache(&self) -> bool {
+    // bust when upgrading, but not downgrading
+    version_gt(&self.wasm_cache_version, WASMER_COMPILER_VERSION)
+  }
+}
+
+fn version_gt(file: &str, current: &str) -> bool {
+  use std::cmp::Ordering;
+
+  for (file, current) in file.split('.').zip(current.split('.')) {
+    if let Ok(file) = file.parse::<usize>() {
+      if let Ok(current) = current.parse::<usize>() {
+        match current.cmp(&file) {
+          Ordering::Greater => return true,
+          Ordering::Less => return false,
+          Ordering::Equal => {
+            // keep searching
+          }
+        }
+      }
+    }
+  }
+  false // equal
 }
 
 #[derive(Clone, Serialize, Deserialize, Debug, PartialEq, Eq)]
@@ -51,22 +82,29 @@ pub struct PluginCacheManifestItem {
 pub fn read_manifest(environment: &impl Environment) -> PluginCacheManifest {
   return match try_deserialize(environment) {
     Ok(manifest) => {
-      if manifest.schema_version != PLUGIN_CACHE_SCHEMA_VERSION {
-        let _ = environment.remove_dir_all(&environment.get_cache_dir().join("plugins"));
+      if manifest.is_different_schema() || manifest.is_new_wasm_cache() {
+        if manifest.is_different_schema() {
+          log_verbose!(environment, "Busting plugins cache due to different schema.");
+        }
+        if manifest.is_new_wasm_cache() {
+          log_verbose!(environment, "Busting plugins cache due to new wasm cache version.");
+        }
+        let _ = environment.remove_dir_all(environment.get_cache_dir().join("plugins"));
         PluginCacheManifest::new()
       } else {
         manifest
       }
     }
-    Err(_) => {
-      let _ = environment.remove_dir_all(&environment.get_cache_dir());
+    Err(err) => {
+      log_verbose!(environment, "Busting plugins cache due to deserialization error: {:#}", err);
+      let _ = environment.remove_dir_all(environment.get_cache_dir().join("plugins"));
       PluginCacheManifest::new()
     }
   };
 
   fn try_deserialize(environment: &impl Environment) -> Result<PluginCacheManifest> {
     let file_path = get_manifest_file_path(environment);
-    match environment.read_file(&file_path) {
+    match environment.read_file(file_path) {
       Ok(text) => Ok(serde_json::from_str::<PluginCacheManifest>(&text)?),
       Err(_) => Ok(PluginCacheManifest::new()),
     }
@@ -76,7 +114,7 @@ pub fn read_manifest(environment: &impl Environment) -> PluginCacheManifest {
 pub fn write_manifest(manifest: &PluginCacheManifest, environment: &impl Environment) -> Result<()> {
   let file_path = get_manifest_file_path(environment);
   let serialized_manifest = serde_json::to_string(&manifest)?;
-  environment.write_file(&file_path, &serialized_manifest)
+  environment.write_file(file_path, &serialized_manifest)
 }
 
 fn get_manifest_file_path(environment: &impl Environment) -> PathBuf {
@@ -97,7 +135,8 @@ mod test {
       .write_file(
         &environment.get_cache_dir().join("plugin-cache-manifest.json"),
         r#"{
-    "schemaVersion": 6,
+    "schemaVersion": 7,
+    "wasmCacheVersion": "99.9.9",
     "plugins": {
         "a": {
             "createdTime": 123,
@@ -142,6 +181,8 @@ mod test {
       .unwrap();
 
     let mut expected_manifest = PluginCacheManifest::new();
+    // should not change a newer version
+    expected_manifest.wasm_cache_version = "99.9.9".to_string();
     expected_manifest.add_item(
       String::from("a"),
       PluginCacheManifestItem {
@@ -197,6 +238,37 @@ mod test {
     assert_eq!(read_manifest(&environment), expected_manifest);
   }
 
+  #[test]
+  fn should_cache_bust_for_old_wasm_cache_version() {
+    let environment = TestEnvironment::new();
+    environment
+      .write_file(
+        &environment.get_cache_dir().join("plugin-cache-manifest.json"),
+        r#"{
+    "schemaVersion": 7,
+    "wasmCacheVersion": "0.1.0",
+    "plugins": {
+        "a": {
+            "createdTime": 123,
+            "info": {
+                "name": "dprint-plugin-typescript",
+                "version": "0.1.0",
+                "configKey": "typescript",
+                "fileExtensions": [".ts"],
+                "helpUrl": "help url",
+                "configSchemaUrl": "schema url"
+            }
+        }
+    }
+}"#,
+      )
+      .unwrap();
+
+    // cache busts since the wasm cache version is old
+    let expected_manifest = PluginCacheManifest::new();
+    assert_eq!(read_manifest(&environment), expected_manifest);
+  }
+
   #[test]
   fn should_not_error_for_old_manifest() {
     let environment = TestEnvironment::new();
@@ -291,4 +363,25 @@ mod test {
     // in a non-deterministic order.
     assert_eq!(read_manifest(&environment), manifest);
   }
+
+  #[test]
+  fn test_version_gt() {
+    assert!(!version_gt("1.1.0", "1.1.0"));
+    assert!(version_gt("1.1.0", "1.1.1"));
+    assert!(version_gt("1.1.0", "1.1.2"));
+    assert!(version_gt("1.1.0", "1.2.0"));
+    assert!(!version_gt("1.1.0", "1.0.0"));
+    assert!(version_gt("1.1.0", "2.1.0"));
+    assert!(!version_gt("1.1.0", "0.1.0"));
+  }
+
+  #[test]
+  fn is_new_wasm_cache() {
+    let mut manifest = PluginCacheManifest::new();
+    assert!(!manifest.is_new_wasm_cache());
+    manifest.wasm_cache_version = "0.0.1".to_string();
+    assert!(manifest.is_new_wasm_cache());
+    manifest.wasm_cache_version = "100.0.1".to_string();
+    assert!(!manifest.is_new_wasm_cache());
+  }
 }
