@@ -1,11 +1,12 @@
 use std::io::Write;
+use std::path::PathBuf;
 use std::sync::Arc;
 
 use anyhow::Result;
 use crossterm::style::Stylize;
+use once_cell::sync::Lazy;
 
 use crate::arg_parser::parse_args;
-use crate::cache::Cache;
 use crate::environment::TestEnvironment;
 use crate::plugins::CompilationResult;
 use crate::plugins::PluginCache;
@@ -14,42 +15,44 @@ use crate::plugins::PluginsCollection;
 use crate::run_cli::run_cli;
 use crate::utils::TestStdInReader;
 
-// this should automatically be built when building the workspace
-#[cfg(all(target_os = "windows", debug_assertions))]
-pub static PROCESS_PLUGIN_EXE_BYTES: &'static [u8] = include_bytes!("../../../target/debug/test-process-plugin.exe");
-#[cfg(all(target_os = "windows", not(debug_assertions)))]
-pub static PROCESS_PLUGIN_EXE_BYTES: &'static [u8] = include_bytes!("../../../target/release/test-process-plugin.exe");
-#[cfg(all(not(target_os = "windows"), debug_assertions))]
-pub static PROCESS_PLUGIN_EXE_BYTES: &'static [u8] = include_bytes!("../../../target/debug/test-process-plugin");
-#[cfg(all(not(target_os = "windows"), not(debug_assertions)))]
-pub static PROCESS_PLUGIN_EXE_BYTES: &'static [u8] = include_bytes!("../../../target/release/test-process-plugin");
+// this file should automatically be built when building the workspace
+pub static TEST_PROCESS_PLUGIN_PATH: Lazy<PathBuf> = Lazy::new(|| {
+  let exe_name = if cfg!(windows) { "test-process-plugin.exe" } else { "test-process-plugin" };
+  let profile_name = if cfg!(debug_assertions) { "debug" } else { "release" };
+  let target_dir = PathBuf::from(env!("CARGO_MANIFEST_DIR")).join("../../target");
+  assert!(target_dir.exists());
+  let file_path = target_dir.join(target_dir.join(env!("TARGET"))).join(profile_name).join(exe_name);
+  let file_path = if file_path.exists() {
+    file_path
+  } else {
+    target_dir.join(profile_name).join(exe_name)
+  };
+  std::fs::canonicalize(&file_path).unwrap_or_else(|err| panic!("Could not canonicalize {}: {:#}", file_path.display(), err))
+});
 
 // Regenerate this by running `./rebuild.sh` in /crates/test-plugin
 pub static WASM_PLUGIN_BYTES: &'static [u8] = include_bytes!("../../test-plugin/test_plugin.wasm");
 // cache these so it only has to be done once across all tests
-lazy_static! {
-  static ref COMPILATION_RESULT: CompilationResult = crate::plugins::compile_wasm(WASM_PLUGIN_BYTES).unwrap();
-}
-lazy_static! {
-  pub static ref PROCESS_PLUGIN_ZIP_BYTES: Vec<u8> = {
-    let buf: Vec<u8> = Vec::new();
-    let w = std::io::Cursor::new(buf);
-    let mut zip = zip::ZipWriter::new(w);
-    let options = zip::write::FileOptions::default().compression_method(zip::CompressionMethod::Stored);
-    zip
-      .start_file(
-        if cfg!(target_os = "windows") {
-          "test-process-plugin.exe"
-        } else {
-          "test-process-plugin"
-        },
-        options,
-      )
-      .unwrap();
-    zip.write(PROCESS_PLUGIN_EXE_BYTES).unwrap();
-    zip.finish().unwrap().into_inner()
-  };
-}
+static COMPILATION_RESULT: Lazy<CompilationResult> = Lazy::new(|| crate::plugins::compile_wasm(WASM_PLUGIN_BYTES).unwrap());
+pub static PROCESS_PLUGIN_ZIP_BYTES: Lazy<Vec<u8>> = Lazy::new(|| {
+  let buf: Vec<u8> = Vec::new();
+  let w = std::io::Cursor::new(buf);
+  let mut zip = zip::ZipWriter::new(w);
+  let options = zip::write::FileOptions::default().compression_method(zip::CompressionMethod::Stored);
+  zip
+    .start_file(
+      if cfg!(target_os = "windows") {
+        "test-process-plugin.exe"
+      } else {
+        "test-process-plugin"
+      },
+      options,
+    )
+    .unwrap();
+  let file_bytes = std::fs::read(&*TEST_PROCESS_PLUGIN_PATH).unwrap();
+  zip.write(&file_bytes).unwrap();
+  zip.finish().unwrap().into_inner()
+});
 
 pub fn run_test_cli(args: Vec<&str>, environment: &TestEnvironment) -> Result<()> {
   run_test_cli_with_stdin(args, environment, TestStdInReader::default())
@@ -59,7 +62,6 @@ pub fn run_test_cli_with_stdin(args: Vec<&str>, environment: &TestEnvironment, s
   let mut args: Vec<String> = args.into_iter().map(String::from).collect();
   args.insert(0, String::from(""));
   environment.set_wasm_compile_result(COMPILATION_RESULT.clone());
-  let cache = Arc::new(Cache::new(environment.clone()));
   let plugin_cache = Arc::new(PluginCache::new(environment.clone()));
   let plugin_pools = Arc::new(PluginsCollection::new(environment.clone()));
   let plugin_resolver = PluginResolver::new(environment.clone(), plugin_cache, plugin_pools.clone());
@@ -70,7 +72,7 @@ pub fn run_test_cli_with_stdin(args: Vec<&str>, environment: &TestEnvironment, s
   environment.run_in_runtime({
     let environment = environment.clone();
     async move {
-      let result = run_cli(&args, &environment, &cache, &plugin_resolver, plugin_pools.clone()).await;
+      let result = run_cli(&args, &environment, &plugin_resolver, plugin_pools.clone()).await;
       plugin_pools.drop_and_shutdown_initialized().await;
       result
     }
@@ -143,7 +145,7 @@ pub fn get_expected_help_text() -> &'static str {
     "dprint ",
     env!("CARGO_PKG_VERSION"),
     r#"
-Copyright 2020-2022 by David Sherret
+Copyright 2020-2023 by David Sherret
 
 Auto-formats source code based on the specified plugins.
 
@@ -165,7 +167,7 @@ SUBCOMMANDS:
 More details at `dprint help <SUBCOMMAND>`
 
 OPTIONS:
-  -c, --config <config>          Path or url to JSON configuration file. Defaults to dprint.json or .dprint.json in current or ancestor directory when not provided.
+  -c, --config <config>          Path or url to JSON configuration file. Defaults to dprint.json(c) or .dprint.json(c) in current or ancestor directory when not provided.
       --plugins <urls/files>...  List of urls or file paths of plugins to use. This overrides what is specified in the config file.
       --verbose                  Prints additional diagnostic information.
 
