@@ -2,9 +2,8 @@ use anyhow::bail;
 use anyhow::Result;
 use url::Url;
 
+use super::get_bytes_hash;
 use super::PathSource;
-use crate::cache::Cache;
-use crate::cache::CreateCacheItemOptions;
 use crate::environment::CanonicalizedPathBuf;
 use crate::environment::Environment;
 
@@ -43,43 +42,34 @@ impl ResolvedPath {
   }
 }
 
-pub fn resolve_url_or_file_path<TEnvironment: Environment>(
-  url_or_file_path: &str,
-  base: &PathSource,
-  cache: &Cache<TEnvironment>,
-  environment: &TEnvironment,
-) -> Result<ResolvedPath> {
+pub fn resolve_url_or_file_path<TEnvironment: Environment>(url_or_file_path: &str, base: &PathSource, environment: &TEnvironment) -> Result<ResolvedPath> {
   let path_source = resolve_url_or_file_path_to_path_source(url_or_file_path, base, environment)?;
 
   match path_source {
-    PathSource::Remote(path_source) => resolve_url(&path_source.url, cache, environment),
+    PathSource::Remote(path_source) => resolve_url(&path_source.url, environment),
     PathSource::Local(path_source) => Ok(ResolvedPath::local(path_source.path)),
   }
 }
 
-fn resolve_url<TEnvironment: Environment>(url: &Url, cache: &Cache<TEnvironment>, environment: &TEnvironment) -> Result<ResolvedPath> {
-  let cache_key = format!("url:{}", url.as_str());
+fn resolve_url<TEnvironment: Environment>(url: &Url, environment: &TEnvironment) -> Result<ResolvedPath> {
   let mut is_first_download = false;
 
-  let cache_item = if let Some(cache_item) = cache.get_cache_item(&cache_key) {
-    cache_item
-  } else {
-    // download and save
-    let file_bytes = environment.download_file_err_404(url.as_str())?;
-    is_first_download = true;
-    cache.create_cache_item(CreateCacheItemOptions {
-      key: cache_key,
-      extension: "tmp",
-      bytes: Some(&file_bytes),
-      meta_data: None,
-    })?
-  };
+  let cache_dir = environment.get_cache_dir().join_panic_relative("remote");
+  environment.mk_dir_all(&cache_dir)?;
 
-  Ok(ResolvedPath::remote(
-    cache.resolve_cache_item_file_path(&cache_item),
-    url.clone(),
-    is_first_download,
-  ))
+  let url_hash = get_bytes_hash(url.as_str().as_bytes());
+  let file_path = cache_dir.join_panic_relative(url_hash.to_string());
+
+  if !environment.path_exists(&file_path) {
+    is_first_download = true;
+    let file_bytes = environment.download_file_err_404(url.as_str())?;
+    let temp_path = file_path.as_ref().with_extension(".tmp");
+    // atomic save
+    environment.write_file_bytes(&temp_path, &file_bytes)?;
+    environment.rename(&temp_path, &file_path)?;
+  }
+
+  Ok(ResolvedPath::remote(file_path, url.clone(), is_first_download))
 }
 
 pub fn fetch_file_or_url_bytes(url_or_file_path: &PathSource, environment: &impl Environment) -> Result<Vec<u8>> {
@@ -141,7 +131,8 @@ fn is_absolute_windows_file_path(value: &str) -> bool {
 
 #[cfg(test)]
 mod tests {
-  use crate::cache::Cache;
+  use std::path::PathBuf;
+
   use crate::environment::TestEnvironment;
   use pretty_assertions::assert_eq;
 
@@ -152,17 +143,19 @@ mod tests {
   fn should_resolve_a_url() {
     let environment = TestEnvironment::new();
     environment.add_remote_file("https://dprint.dev/test.json", "t".as_bytes());
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_local(CanonicalizedPathBuf::new_for_testing("/"));
-    let result = resolve_url_or_file_path("https://dprint.dev/test.json", &base, &cache, &environment).unwrap();
-    assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("/cache/test.tmp"));
+    let url = "https://dprint.dev/test.json";
+    let url_hash = get_bytes_hash(url.as_bytes());
+    let cache_file_path = environment.get_cache_dir().join("remote").join(url_hash.to_string());
+    let result = resolve_url_or_file_path(url, &base, &environment).unwrap();
+    assert_eq!(result.file_path.as_ref(), cache_file_path);
     assert_eq!(result.is_remote(), true);
     assert_eq!(result.is_first_download, true);
     assert_eq!(environment.read_file(&result.file_path).unwrap(), "t");
 
     // should get a second time from the cache
-    let result = resolve_url_or_file_path("https://dprint.dev/test.json", &base, &cache, &environment).unwrap();
-    assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("/cache/test.tmp"));
+    let result = resolve_url_or_file_path(url, &base, &environment).unwrap();
+    assert_eq!(result.file_path.as_ref(), cache_file_path);
     assert_eq!(result.is_remote(), true);
     assert_eq!(result.is_first_download, false);
   }
@@ -171,20 +164,18 @@ mod tests {
   fn should_resolve_a_relative_path_to_base_url() {
     let environment = TestEnvironment::new();
     environment.add_remote_file("https://dprint.dev/asdf/test/test.json", "t".as_bytes());
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_remote(Url::parse("https://dprint.dev/asdf/").unwrap());
-    let result = resolve_url_or_file_path("test/test.json", &base, &cache, &environment).unwrap();
+    let result = resolve_url_or_file_path("test/test.json", &base, &environment).unwrap();
     assert_eq!(result.is_remote(), true);
-    assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("/cache/test.tmp"));
+    assert_eq!(result.file_path.as_ref(), PathBuf::from("/cache").join("remote").join("13688467613984252730"));
   }
 
   #[cfg(windows)]
   #[test]
   fn should_resolve_a_file_url_on_windows() {
     let environment = TestEnvironment::new();
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_local(CanonicalizedPathBuf::new_for_testing("V:\\"));
-    let result = resolve_url_or_file_path("file://C:/test/test.json", &base, &cache, &environment).unwrap();
+    let result = resolve_url_or_file_path("file://C:/test/test.json", &base, &environment).unwrap();
     assert_eq!(result.is_local(), true);
     assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("C:\\test\\test.json"));
   }
@@ -193,9 +184,8 @@ mod tests {
   #[test]
   fn should_resolve_a_file_url_on_unix() {
     let environment = TestEnvironment::new();
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_local(CanonicalizedPathBuf::new_for_testing("/"));
-    let result = resolve_url_or_file_path("file:///test/test.json", &base, &cache, &environment).unwrap();
+    let result = resolve_url_or_file_path("file:///test/test.json", &base, &environment).unwrap();
     assert_eq!(result.is_local(), true);
     assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("/test/test.json"));
   }
@@ -204,9 +194,8 @@ mod tests {
   #[test]
   fn should_resolve_an_absolute_path_on_windows() {
     let environment = TestEnvironment::new();
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_local(CanonicalizedPathBuf::new_for_testing("V:\\"));
-    let result = resolve_url_or_file_path("C:\\test\\test.json", &base, &cache, &environment).unwrap();
+    let result = resolve_url_or_file_path("C:\\test\\test.json", &base, &environment).unwrap();
     assert_eq!(result.is_local(), true);
     assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("C:\\test\\test.json"));
   }
@@ -215,9 +204,8 @@ mod tests {
   #[test]
   fn should_resolve_an_absolute_path_on_windows_using_forward_slashes() {
     let environment = TestEnvironment::new();
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_local(CanonicalizedPathBuf::new_for_testing("V:\\"));
-    let result = resolve_url_or_file_path("C:/test/test.json", &base, &cache, &environment).unwrap();
+    let result = resolve_url_or_file_path("C:/test/test.json", &base, &environment).unwrap();
     assert_eq!(result.is_local(), true);
     assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("C:\\test\\test.json"));
   }
@@ -225,9 +213,8 @@ mod tests {
   #[test]
   fn should_resolve_a_relative_file_path() {
     let environment = TestEnvironment::new();
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_local(CanonicalizedPathBuf::new_for_testing("/"));
-    let result = resolve_url_or_file_path("test/test.json", &base, &cache, &environment).unwrap();
+    let result = resolve_url_or_file_path("test/test.json", &base, &environment).unwrap();
     assert_eq!(result.is_local(), true);
     assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("/test/test.json"));
   }
@@ -235,9 +222,8 @@ mod tests {
   #[test]
   fn should_resolve_a_file_path_relative_to_base_path() {
     let environment = TestEnvironment::new();
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_local(CanonicalizedPathBuf::new_for_testing("/other"));
-    let result = resolve_url_or_file_path("test/test.json", &base, &cache, &environment).unwrap();
+    let result = resolve_url_or_file_path("test/test.json", &base, &environment).unwrap();
     assert_eq!(result.is_local(), true);
     assert_eq!(result.file_path, CanonicalizedPathBuf::new_for_testing("/other/test/test.json"));
   }
@@ -245,11 +231,8 @@ mod tests {
   #[test]
   fn should_error_when_url_cannot_be_resolved() {
     let environment = TestEnvironment::new();
-    let cache = Cache::new(environment.clone());
     let base = PathSource::new_local(CanonicalizedPathBuf::new_for_testing("/other"));
-    let err = resolve_url_or_file_path("https://dprint.dev/test.json", &base, &cache, &environment)
-      .err()
-      .unwrap();
+    let err = resolve_url_or_file_path("https://dprint.dev/test.json", &base, &environment).err().unwrap();
     assert_eq!(err.to_string(), "Error downloading https://dprint.dev/test.json - 404 Not Found");
   }
 
