@@ -10,32 +10,32 @@ const exePath = path.join(__dirname, os.platform() === "win32" ? "dprint.exe" :
 
 if (!fs.existsSync(exePath)) {
   require("./install_api").runInstall().then(() => {
-    runDprintExe();
+    // I'm not sure why (I think due zip extraction), but the executable
+    // doesn't seem fully ready unless waiting for the next tick
+    setTimeout(() => {
+      runDprintExe();
+    }, 0);
   }).catch(err => {
     console.error(err);
-    process.exit(child_process.exitCode || 1);
+    process.exit(1);
   });
 } else {
   runDprintExe();
 }
 
 function runDprintExe() {
-  try {
-    const result = child_process.spawnSync(
-      exePath,
-      process.argv.slice(2),
-      { stdio: "inherit" },
-    );
-    if (result.error) {
-      throw result.error;
-    }
-
-    throwIfNoExePath();
-
-    process.exitCode = result.status;
-  } catch (err) {
-    throw err;
+  const result = child_process.spawnSync(
+    exePath,
+    process.argv.slice(2),
+    { stdio: "inherit" },
+  );
+  if (result.error) {
+    throw result.error;
   }
+
+  throwIfNoExePath();
+
+  process.exitCode = result.status;
 }
 
 function throwIfNoExePath() {
